@@ -7,25 +7,36 @@ from csvkit.cli import CSVKitUtility, match_column_identifier
 
 class CSVJoin(CSVKitUtility):
     description = 'Execute a SQL-like join to merge CSV files on a specified column or columns.'
-    epilog = 'Note that the join operation requires reading all files into memory. Don\'t try this on very large files.'
+    epilog = "Note that the join operation requires reading all files into memory. Don't try this on very large files."
     # Override 'f' because the utility accepts multiple files.
     override_flags = ['f']
 
     def add_arguments(self):
-        self.argparser.add_argument(metavar='FILE', nargs='*', dest='input_paths', default=['-'],
-                                    help='The CSV files to operate on. If only one is specified, it will be copied to STDOUT.')
-        self.argparser.add_argument('-c', '--columns', dest='columns',
-                                    help='The column name(s) on which to join. Should be either one name (or index) or a comma-separated list with one name (or index) for each file, in the same order that the files were specified. May also be left unspecified, in which case the two files will be joined sequentially without performing any matching.')
-        self.argparser.add_argument('--outer', dest='outer_join', action='store_true',
-                                    help='Perform a full outer join, rather than the default inner join.')
-        self.argparser.add_argument('--left', dest='left_join', action='store_true',
-                                    help='Perform a left outer join, rather than the default inner join. If more than two files are provided this will be executed as a sequence of left outer joins, starting at the left.')
-        self.argparser.add_argument('--right', dest='right_join', action='store_true',
-                                    help='Perform a right outer join, rather than the default inner join. If more than two files are provided this will be executed as a sequence of right outer joins, starting at the right.')
-        self.argparser.add_argument('-y', '--snifflimit', dest='sniff_limit', type=int,
-                                    help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing entirely.')
-        self.argparser.add_argument('-I', '--no-inference', dest='no_inference', action='store_true',
-                                    help='Disable type inference when parsing CSV input.')
+        self.argparser.add_argument(
+            metavar='FILE', nargs='*', dest='input_paths', default=['-'],
+            help='The CSV files to operate on. If only one is specified, it will be copied to STDOUT.')
+        self.argparser.add_argument(
+            '-c', '--columns', dest='columns',
+            help='The column name(s) on which to join. Should be either one name (or index) or a comma-separated list '
+                 'with one name (or index) per file, in the same order in which the files were specified. If not '
+                 'specified, the two files will be joined sequentially without matching.')
+        self.argparser.add_argument(
+            '--outer', dest='outer_join', action='store_true',
+            help='Perform a full outer join, rather than the default inner join.')
+        self.argparser.add_argument(
+            '--left', dest='left_join', action='store_true',
+            help='Perform a left outer join, rather than the default inner join. If more than two files are provided '
+                 'this will be executed as a sequence of left outer joins, starting at the left.')
+        self.argparser.add_argument(
+            '--right', dest='right_join', action='store_true',
+            help='Perform a right outer join, rather than the default inner join. If more than two files are provided '
+                 'this will be executed as a sequence of right outer joins, starting at the right.')
+        self.argparser.add_argument(
+            '-y', '--snifflimit', dest='sniff_limit', type=int,
+            help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing.')
+        self.argparser.add_argument(
+            '-I', '--no-inference', dest='no_inference', action='store_true',
+            help='Disable type inference when parsing CSV input.')
 
     def main(self):
         self.input_files = []
@@ -43,7 +54,8 @@ class CSVJoin(CSVKitUtility):
                 join_column_names = join_column_names * len(self.input_files)
 
             if len(join_column_names) != len(self.input_files):
-                self.argparser.error('The number of join column names must match the number of files, or be a single column name that exists in all files.')
+                self.argparser.error('The number of join column names must match the number of files, or be a single '
+                                     'column name that exists in all files.')
 
         if (self.args.left_join or self.args.right_join or self.args.outer_join) and not self.args.columns:
             self.argparser.error('You must provide join column names when performing an outer join.')
