@@ -9,16 +9,21 @@ class CSVLook(CSVKitUtility):
     description = 'Render a CSV file in the console as a Markdown-compatible, fixed-width table.'
 
     def add_arguments(self):
-        self.argparser.add_argument('--max-rows', dest='max_rows', type=int,
-                                    help='The maximum number of rows to display before truncating the data.')
-        self.argparser.add_argument('--max-columns', dest='max_columns', type=int,
-                                    help='The maximum number of columns to display before truncating the data.')
-        self.argparser.add_argument('--max-column-width', dest='max_column_width', type=int,
-                                    help='Truncate all columns to at most this width. The remainder will be replaced with ellipsis.')
-        self.argparser.add_argument('-y', '--snifflimit', dest='sniff_limit', type=int,
-                                    help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing entirely.')
-        self.argparser.add_argument('-I', '--no-inference', dest='no_inference', action='store_true',
-                                    help='Disable type inference when parsing the input.')
+        self.argparser.add_argument(
+            '--max-rows', dest='max_rows', type=int,
+            help='The maximum number of rows to display before truncating the data.')
+        self.argparser.add_argument(
+            '--max-columns', dest='max_columns', type=int,
+            help='The maximum number of columns to display before truncating the data.')
+        self.argparser.add_argument(
+            '--max-column-width', dest='max_column_width', type=int,
+            help='Truncate all columns to at most this width. The remainder will be replaced with ellipsis.')
+        self.argparser.add_argument(
+            '-y', '--snifflimit', dest='sniff_limit', type=int,
+            help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing.')
+        self.argparser.add_argument(
+            '-I', '--no-inference', dest='no_inference', action='store_true',
+            help='Disable type inference when parsing the input.')
 
     def main(self):
         if self.additional_input_expected():
