@@ -9,16 +9,22 @@ class CSVSort(CSVKitUtility):
     description = 'Sort CSV files. Like the Unix "sort" command, but for tabular data.'
 
     def add_arguments(self):
-        self.argparser.add_argument('-n', '--names', dest='names_only', action='store_true',
-                                    help='Display column names and indices from the input CSV and exit.')
-        self.argparser.add_argument('-c', '--columns', dest='columns',
-                                    help='A comma separated list of column indices, names or ranges to sort by, e.g. "1,id,3-5". Defaults to all columns.')
-        self.argparser.add_argument('-r', '--reverse', dest='reverse', action='store_true',
-                                    help='Sort in descending order.')
-        self.argparser.add_argument('-y', '--snifflimit', dest='sniff_limit', type=int,
-                                    help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing entirely.')
-        self.argparser.add_argument('-I', '--no-inference', dest='no_inference', action='store_true',
-                                    help='Disable type inference when parsing the input.')
+        self.argparser.add_argument(
+            '-n', '--names', dest='names_only', action='store_true',
+            help='Display column names and indices from the input CSV and exit.')
+        self.argparser.add_argument(
+            '-c', '--columns', dest='columns',
+            help='A comma-separated list of column indices, names or ranges to sort by, e.g. "1,id,3-5". '
+                 'Defaults to all columns.')
+        self.argparser.add_argument(
+            '-r', '--reverse', dest='reverse', action='store_true',
+            help='Sort in descending order.')
+        self.argparser.add_argument(
+            '-y', '--snifflimit', dest='sniff_limit', type=int,
+            help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing.')
+        self.argparser.add_argument(
+            '-I', '--no-inference', dest='no_inference', action='store_true',
+            help='Disable type inference when parsing the input.')
 
     def main(self):
         if self.args.names_only:
