@@ -4,16 +4,16 @@ import sys
 from os.path import splitext
 
 import agate
-import agatedbf  # noqa
-import agateexcel  # noqa
+import agatedbf  # noqa: F401
+import agateexcel  # noqa: F401
 import openpyxl
 import six
 import xlrd
 
 from csvkit import convert
+from csvkit.cli import CSVKitUtility
 from csvkit.convert.fixed import fixed2csv
 from csvkit.convert.geojs import geojson2csv
-from csvkit.cli import CSVKitUtility
 
 SUPPORTED_FORMATS = ['csv', 'dbf', 'fixed', 'geojson', 'json', 'ndjson', 'xls', 'xlsx']
 
@@ -32,26 +32,36 @@ class In2CSV(CSVKitUtility):
             else:
                 return bytestring
 
-        self.argparser.add_argument(metavar='FILE', nargs='?', dest='input_path',
-                                    help='The CSV file to operate on. If omitted, will accept input as piped data via STDIN.')
-        self.argparser.add_argument('-f', '--format', dest='filetype',
-                                    help='The format of the input file. If not specified will be inferred from the file type. Supported formats: %s.' % ', '.join(sorted(SUPPORTED_FORMATS)))
-        self.argparser.add_argument('-s', '--schema', dest='schema',
-                                    help='Specify a CSV-formatted schema file for converting fixed-width files.  See documentation for details.')
-        self.argparser.add_argument('-k', '--key', dest='key',
-                                    help='Specify a top-level key to use look within for a list of objects to be converted when processing JSON.')
-        self.argparser.add_argument('-n', '--names', dest='names_only', action='store_true',
-                                    help='Display sheet names from the input Excel file.')
-        self.argparser.add_argument('--sheet', dest='sheet', type=option_parser,
-                                    help='The name of the Excel sheet to operate on.')
-        self.argparser.add_argument('--write-sheets', dest='write_sheets', type=option_parser,
-                                    help='The names of the Excel sheets to write to files, or "-" to write all sheets.')
-        self.argparser.add_argument('--encoding-xls', dest='encoding_xls',
-                                    help='Specify the encoding of the input XLS file.')
-        self.argparser.add_argument('-y', '--snifflimit', dest='sniff_limit', type=int,
-                                    help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing entirely.')
-        self.argparser.add_argument('-I', '--no-inference', dest='no_inference', action='store_true',
-                                    help='Disable type inference (and --locale, --date-format, --datetime-format) when parsing CSV input.')
+        self.argparser.add_argument(
+            metavar='FILE', nargs='?', dest='input_path',
+            help='The CSV file to operate on. If omitted, will accept input as piped data via STDIN.')
+        self.argparser.add_argument(
+            '-f', '--format', dest='filetype', choices=SUPPORTED_FORMATS,
+            help='The format of the input file. If not specified will be inferred from the file type.')
+        self.argparser.add_argument(
+            '-s', '--schema', dest='schema',
+            help='Specify a CSV-formatted schema file for converting fixed-width files. See web documentation.')
+        self.argparser.add_argument(
+            '-k', '--key', dest='key',
+            help='Specify a top-level key to look within for a list of objects to be converted when processing JSON.')
+        self.argparser.add_argument(
+            '-n', '--names', dest='names_only', action='store_true',
+            help='Display sheet names from the input Excel file.')
+        self.argparser.add_argument(
+            '--sheet', dest='sheet', type=option_parser,
+            help='The name of the Excel sheet to operate on.')
+        self.argparser.add_argument(
+            '--write-sheets', dest='write_sheets', type=option_parser,
+            help='The names of the Excel sheets to write to files, or "-" to write all sheets.')
+        self.argparser.add_argument(
+            '--encoding-xls', dest='encoding_xls',
+            help='Specify the encoding of the input XLS file.')
+        self.argparser.add_argument(
+            '-y', '--snifflimit', dest='sniff_limit', type=int,
+            help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing.')
+        self.argparser.add_argument(
+            '-I', '--no-inference', dest='no_inference', action='store_true',
+            help='Disable type inference (and --locale, --date-format, --datetime-format) when parsing CSV input.')
 
     def open_excel_input_file(self, path):
         if not path or path == '-':
@@ -77,8 +87,6 @@ class In2CSV(CSVKitUtility):
         # Determine the file type.
         if self.args.filetype:
             filetype = self.args.filetype
-            if filetype not in SUPPORTED_FORMATS:
-                self.argparser.error('"%s" is not a supported format' % self.args.filetype)
         elif self.args.schema:
             filetype = 'fixed'
         elif self.args.key:
@@ -88,7 +96,8 @@ class In2CSV(CSVKitUtility):
                 self.argparser.error('You must specify a format when providing input as piped data via STDIN.')
             filetype = convert.guess_format(path)
             if not filetype:
-                self.argparser.error('Unable to automatically determine the format of the input file. Try specifying a format with --format.')
+                self.argparser.error('Unable to automatically determine the format of the input file. Try specifying '
+                                     'a format with --format.')
 
         if self.args.names_only:
             if filetype in ('xls', 'xlsx'):
@@ -127,7 +136,13 @@ class In2CSV(CSVKitUtility):
             kwargs['column_types'] = self.get_column_types()
 
         # Convert the file.
-        if filetype == 'csv' and self.args.no_inference and not self.args.no_header_row and not self.args.skip_lines and self.args.sniff_limit == 0:
+        if (
+            filetype == 'csv'
+            and self.args.no_inference
+            and not self.args.no_header_row
+            and not self.args.skip_lines
+            and self.args.sniff_limit == 0
+        ):
             reader = agate.csv.reader(self.input_file, **self.reader_kwargs)
             writer = agate.csv.writer(self.output_file, **self.writer_kwargs)
             writer.writerows(reader)
@@ -143,7 +158,8 @@ class In2CSV(CSVKitUtility):
             elif filetype == 'ndjson':
                 table = agate.Table.from_json(self.input_file, key=self.args.key, newline=True, **kwargs)
             elif filetype == 'xls':
-                table = agate.Table.from_xls(self.input_file, sheet=self.args.sheet, encoding_override=self.args.encoding_xls, **kwargs)
+                table = agate.Table.from_xls(self.input_file, sheet=self.args.sheet,
+                                             encoding_override=self.args.encoding_xls, **kwargs)
             elif filetype == 'xlsx':
                 table = agate.Table.from_xlsx(self.input_file, sheet=self.args.sheet, **kwargs)
             elif filetype == 'dbf':
@@ -164,7 +180,8 @@ class In2CSV(CSVKitUtility):
                 sheets = [int(sheet) if sheet.isdigit() else sheet for sheet in self.args.write_sheets.split(',')]
 
             if filetype == 'xls':
-                tables = agate.Table.from_xls(self.input_file, sheet=sheets, encoding_override=self.args.encoding_xls, **kwargs)
+                tables = agate.Table.from_xls(self.input_file, sheet=sheets,
+                                              encoding_override=self.args.encoding_xls, **kwargs)
             elif filetype == 'xlsx':
                 tables = agate.Table.from_xlsx(self.input_file, sheet=sheets, **kwargs)
 
