@@ -12,16 +12,21 @@ class SQL2CSV(CSVKitUtility):
     override_flags = 'f,b,d,e,H,K,L,p,q,S,t,u,z,blanks,date-format,datetime-format,zero'.split(',')
 
     def add_arguments(self):
-        self.argparser.add_argument('--db', dest='connection_string', default='sqlite://',
-                                    help='An sqlalchemy connection string to connect to a database.',)
-        self.argparser.add_argument(metavar='FILE', nargs='?', dest='input_path',
-                                    help='The file to use as SQL query. If both FILE and QUERY are omitted, query will be read as piped data via STDIN.')
-        self.argparser.add_argument('--query',
-                                    help="The SQL query to execute. If specified, it overrides FILE and STDIN.")
-        self.argparser.add_argument('-e', '--encoding', dest='encoding', default='utf-8',
-                                    help='Specify the encoding of the input query file.')
-        self.argparser.add_argument('-H', '--no-header-row', dest='no_header_row', action='store_true',
-                                    help='Do not output column names.')
+        self.argparser.add_argument(
+            '--db', dest='connection_string', default='sqlite://',
+            help='An sqlalchemy connection string to connect to a database.',)
+        self.argparser.add_argument(
+            metavar='FILE', nargs='?', dest='input_path',
+            help='The file to use as SQL query. If FILE and --query are omitted, the query is piped data via STDIN.')
+        self.argparser.add_argument(
+            '--query',
+            help="The SQL query to execute. Overrides FILE and STDIN.")
+        self.argparser.add_argument(
+            '-e', '--encoding', dest='encoding', default='utf-8',
+            help='Specify the encoding of the input query file.')
+        self.argparser.add_argument(
+            '-H', '--no-header-row', dest='no_header_row', action='store_true',
+            help='Do not output column names.')
 
         self.argparser.set_defaults(
             delimiter=None,
@@ -41,12 +46,12 @@ class SQL2CSV(CSVKitUtility):
 
         try:
             engine = create_engine(self.args.connection_string)
-        except ImportError:
+        except ImportError as e:
             raise ImportError("You don't appear to have the necessary database backend installed for connection "
                               "string you're trying to use. Available backends include:\n\nPostgreSQL:\tpip install "
                               "psycopg2\nMySQL:\t\tpip install mysql-connector-python\n\nFor details on connection "
                               "strings and other backends, please see the SQLAlchemy documentation on dialects at:\n\n"
-                              "http://www.sqlalchemy.org/docs/dialects/\n\n")
+                              "http://www.sqlalchemy.org/docs/dialects/\n\n") from e
 
         connection = engine.connect()
 
