@@ -20,7 +20,7 @@ extensions = ['sphinx.ext.autodoc', 'sphinx.ext.intersphinx']
 autodoc_member_order = 'bysource'
 
 intersphinx_mapping = {
-    'python': ('http://docs.python.org/3.5/', None)
+    'python': ('https://docs.python.org/3.5/', None)
 }
 
 # Add any paths that contain templates here, relative to this directory.
@@ -41,9 +41,9 @@ copyright = u'2016, Christopher Groskopf'
 # built documents.
 #
 # The short X.Y version.
-version = '1.0.5'
+version = '1.0.6'
 # The full version, including alpha/beta/rc tags.
-release = '1.0.5'
+release = version
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
