@@ -2,9 +2,8 @@
 
 import sys
 
-import six
-
 import agate
+import six
 
 try:
     from mock import patch
@@ -12,7 +11,7 @@ except ImportError:
     from unittest.mock import patch
 
 from csvkit.utilities.csvstat import CSVStat, launch_new_instance
-from tests.utils import CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests
+from tests.utils import ColumnsTests, CSVKitTestCase, EmptyFileTests, NamesTests
 
 
 class TestCSVStat(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
@@ -47,7 +46,7 @@ class TestCSVStat(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
 
     def test_count_only(self):
         output = self.get_output(['--count', 'examples/realdata/ks_1033_data.csv'])
-        self.assertEqual(output, 'Row count: 1575\n')
+        self.assertEqual(output, '1575\n')
 
     def test_unique(self):
         output = self.get_output(['-c', 'county', 'examples/realdata/ks_1033_data.csv'])
